summaryrefslogtreecommitdiff
path: root/src/categories.h
diff options
context:
space:
mode:
authorTannin <devnull@localhost>2013-03-27 12:32:23 +0100
committerTannin <devnull@localhost>2013-03-27 12:32:23 +0100
commit10485e15e4de3e1a6c30733ad2d4850591d31509 (patch)
treed4ca59328823e5d6ff8be6f403f0eb8c5c7cf05a /src/categories.h
parentec0ea9df8dabe686d3256665c7ed638660309915 (diff)
- some cleanup to hookdll
- exchanged grouping proxies with existing solution from the kde project
Diffstat (limited to 'src/categories.h')
-rw-r--r--src/categories.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/categories.h b/src/categories.h
index 47b15711..8ec573b2 100644
--- a/src/categories.h
+++ b/src/categories.h
@@ -157,12 +157,17 @@ public:
public:
- /**
- * @brief retrieve a reference to the singleton instance
- *
- * @return the reference to the singleton
- **/
- static CategoryFactory &instance();
+ /**
+ * @brief retrieve a reference to the singleton instance
+ *
+ * @return the reference to the singleton
+ **/
+ static CategoryFactory &instance();
+
+ /**
+ * @return path to the file that contains the categories list
+ */
+ static QString categoriesFilePath();
private: